@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::TravisCI::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Integrating the generation of .travis.yml into your dzil
-$Dist::Zilla::Plugin::TravisCI::VERSION = '0.007';
+$Dist::Zilla::Plugin::TravisCI::VERSION = '0.008';
 use Moose;
 use Path::Tiny qw( path );
 use Dist::Zilla::File::FromCode;
@@ -52,8 +52,7 @@ sub gather_files {
     name              => '.travis.yml',
     code_return_type  => 'text',        # YAML::Dump returns text
     code              => sub {
-      my $structure = $self->build_travis_yml;
-      return YAML::Dump($structure);
+      return $self->build_travis_yml_str;
     },
   );
   $self->add_file($file);
@@ -63,13 +62,20 @@ sub gather_files {
 sub after_build {
   my $self = shift;
   return unless grep { $_ eq 'root' } @{ $self->write_to };
-  require YAML;
-  YAML::DumpFile(path($self->zilla->root,'.travis.yml')->stringify,  $self->build_travis_yml );
+  path($self->zilla->root,'.travis.yml')->spew_utf8($self->build_travis_yml_str);
   return;
 }
 
 sub _get_exports { shift; map { "export ".$_ } @_ }
 
+sub build_travis_yml_str {
+  my ($self) = @_;
+  my $structure = $self->build_travis_yml;
+  require YAML;
+  local $YAML::QuoteNumericStrings=1;
+  return YAML::Dump($structure);
+}
+
 sub build_travis_yml {
 	my ($self, $is_build_branch) = @_;
 
@@ -190,7 +196,7 @@ Dist::Zilla::Plugin::TravisCI - Integrating the generation of .travis.yml into y
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
